# PyBirds
Author: Ouyang Ruofei

Email: rfouyang@gmail.com

# Introduction
PyBIrds is a Risk Model python package.

It includes the following functions:
* WOE encoding
* Logistic regression benchmark
* Score binning methods

# Installment Instruction
pip install pybirds